==> moodle_1.3.1.orig.tar.gz: moodle/lang/de/quiz.php <==
<?PHP // $Id: quiz.php,v 1.42 2004/04/27 16:48:40 ralf-bonn Exp $ 
      // quiz.php - created with Moodle 1.3 development (2004041800)


$string['acceptederror'] = 'Akzeptierter Fehler';
$string['addingquestions'] = 'Diese Spalte der Seite ist zum Verwalten von Testfragen. Fragen werden in Kategorien gespeichert, um sie besser organisieren zu knnen, und knnen von jedem Test Ihres Kurses oder sogar von anderen Kursen (Wenn man \'verffentlichen\' ausgewhlt hat) benutzt werden. <br /><br />Nachdem Sie eine Kategorie erzeugt haben, knnen Sie Fragen erzeugen oder bearbeiten. Sie knnen jede dieser Fragen auswhlen und Ihrem Test in der anderen Spalte hinzufgen.';
$string['addquestions'] = 'Fragen hinzufgen';
$string['addquestionstoquiz'] = 'Frage zu aktuellem Test hinzufgen';
$string['addselectedtoquiz'] = 'Auswahl zum Test hinzufgen';
$string['aiken'] = 'Aiken Format';
$string['allowreview'] = 'Bericht erlauben';
$string['alreadysubmitted'] = 'Es sieht so aus, als htten Sie diesen Versuch schon eingetragen';
$string['alwaysavailable'] = 'Immer verfgbar';
$string['answer'] = 'Antwort';
$string['answerhowmany'] = 'Eine oder mehrere Antworten?';
$string['answersingleno'] = 'Mehrere Antworten erlaubt';
$string['answersingleyes'] = 'Nur eine Antwort';
$string['answerswithacceptederrormarginmustbenumeric'] = 'Antworten mit akzeptiertem Fehler';
$string['answertoolong'] = 'Die Antwort ist nach Zeile $a zu lang (Sie knnen bis zu 255 Zeichen eingeben).';
$string['aon'] = 'AON Format';
$string['attempt'] = 'Versuch $a';
$string['attemptfirst'] = 'Erster Versuch';
$string['attemptincomplete'] = 'Dieser Versuch von $a ist noch nicht vollstndig abgeschlossen.';
$string['attemptlast'] = 'Letzter Versuch';
$string['attemptquiznow'] = 'Test jetzt probieren';
$string['attempts'] = 'Versuche';
$string['attemptsallowed'] = 'Erlaubte Versuche';
$string['attemptsunlimited'] = 'Unbegrenzte Versuche';
$string['backtoquiz'] = 'Zurck zur Testbearbeitung';
$string['bestgrade'] = 'Bestnote';
$string['blackboard'] = 'Blackboard (Lernmanagementsystem)';
$string['calculatedquestion'] = 'Die berechnete Frage in Zeile $a wird nicht untersttzt. Die Frage wird ignoriert.';
$string['caseno'] = 'Nein, Schreibweise ist unwichtig';
$string['casesensitive'] = 'Schreibweise';
$string['caseyes'] = 'Ja, Schreibweise muss stimmen';
$string['categories'] = 'Kategorien';
$string['category'] = 'Kategorie';
$string['categoryinfo'] = 'Kategorie-Information';
$string['categorymove'] = 'Die Kategorie \'$a->name\' enthlt $a->count Fragen. Bitte whlen Sie eine andere Kategorie, um sie zu verschieben.';
$string['categorymoveto'] = 'In diese Kategorie verschieben';
$string['choice'] = 'Auswahl';
$string['choices'] = 'Verfgbare Auswahl';
$string['correctanswer'] = 'Richtige Antwort';
$string['correctanswers'] = 'Richtige Antworten';
$string['corrresp'] = 'richtige Rckantwort';
$string['countdown'] = 'Countdown';
$string['countdownfinished'] = 'Das Test ist beendet, Sie sollten Ihre Antworten jetzt absenden.';
$string['countdowntenminutes'] = 'Das Test endet in 10 Minuten.';
$string['coursetestmanager'] = 'Kurstest Managerformat';
$string['createmultiple'] = 'Mehrere Fragen erstellen';
$string['createnewquestion'] = 'Eine neue Frage anlegen';
$string['custom'] = 'Eigenes Format';
$string['daysavailable'] = 'Tage verfgbar';
$string['default'] = 'Standard';
$string['defaultgrade'] = 'Standard-Note der Frage';
$string['defaultinfo'] = 'Die Standard-Kategorie fr diese Frage';
$string['deleteattemptcheck'] = 'Sind Sie wirklich sicher, dass Sie diese Versuche lschen wollen?';
$string['deletequestioncheck'] = 'Sind Sie sich absolut sicher, dass Sie \'$a\' lschen mchten?';
$string['description'] = 'Beschreibung';
$string['discrimination'] = 'Index fr die Abgrenzung';
$string['eachattemptbuildsonthelast'] = 'Jeder Versuch basiert auf dem Letzten';
$string['editcategories'] = 'Kategorien bearbeiten';
$string['editingdescription'] = 'Eine Beschreibung bearbeiten';
$string['editingmatch'] = 'Eine Zuordnungsfrage bearbeiten';
$string['editingmultianswer'] = 'Eine Frage mit Lckentext bearbeiten';
$string['editingmultichoice'] = 'Eine Frage mit Mehrfachauswahl bearbeiten';
$string['editingnumerical'] = 'Eine numerische Frage bearbeiten';
$string['editingquestion'] = 'Eine Frage bearbeiten';
$string['editingquiz'] = 'Einen Test bearbeiten';
$string['editingrandom'] = 'Eine zufllige Frage bearbeiten';
$string['editingrandomsamatch'] = 'Eine zufllige Kurzantwort-Zuordnung bearbeiten ';
$string['editingshortanswer'] = 'Kurzantwort der Frage bearbeiten';
$string['editingtruefalse'] = 'Ja/Nein-Frage bearbeiten';
$string['editquestions'] = 'Fragen bearbeiten';
$string['errorsdetected'] = '$a Fehler entdeckt';
$string['false'] = 'Falsch';
$string['feedback'] = 'Rckmeldung';
$string['fileformat'] = 'Dateiformat';
$string['filloutoneanswer'] = 'Sie mssen mindestens eine mgliche Antwort geben. Leere Antworten werden ignoriert.';
$string['filloutthreequestions'] = 'Sie mssen mindestens 3 Fragen auswhlen. Leere Fragen werden nicht verwendet';
$string['fillouttwochoices'] = 'Sie mssen mindestens zwei mgliche Antwort geben. Leere Antworten werden ignoriert.';
$string['fractionsaddwrong'] = 'Ihre positiven gewhlten Punktzahlen ergeben keine 100%%

<BR>Statt dessen ergeben Sie $a%%

<BR>Mchten Sie zurck gehen und diese Frage korrigieren?';
$string['fractionsnomax'] = 'Eine dieser Antworten sollte 100%% sein, so dass
<br>es mglich ist, die volle Punktzahl fr diese Frage zu bekommen.

<br>Mchten Sie zurck gehen und diese Frage korrigieren?';
$string['gift'] = 'GIFT Format';
$string['gradeaverage'] = 'Durchschnittsnote';
$string['gradehighest'] = 'Beste Note';
$string['grademethod'] = 'Bewertungsschema';
$string['guestsno'] = 'Entschuldigung, aber Gste knnen den Test nicht sehen oder probieren.';
$string['imagedisplay'] = 'Bild fr die Anzeige';
$string['imagemissing'] = 'Bild in Zeile $a nicht verfgbar. Der Dateiname wird ignoriert';
$string['importquestions'] = 'Eine Frage aus einer Datei importieren';
$string['indivresp'] = 'Rckantwort fr jeden zu jeder Position';
$string['introduction'] = 'Einleitung';
$string['itemanal'] = 'Antwortanalyse des Elements';
$string['listitems'] = 'Liste der Elementes des Tests';
$string['marks'] = 'Punkte';
$string['match'] = 'Zuordnung';
$string['matchanswer'] = 'zugeordnete Antwort';
$string['missinganswer'] = 'Zu wenig :Antworten, :Lx, :Rx Antworten fr Zeile $a. Sie mssen mindestens zwei mgliche Antworten eingeben';
$string['missingcorrectanswer'] = 'Die korrekte Antwort muss angegeben werden';
$string['missingname'] = 'Der Name der Frage fehlt';
$string['missingquestion'] = 'Fehlendes Fragezeichen nach Zeile $a';
$string['missingquestiontext'] = 'Der Text der Frage fehlt';
$string['missingword'] = 'Das Wortformat fehlt';
$string['modulename'] = 'Test';
$string['modulenameplural'] = 'Tests';
$string['multianswer'] = 'Lckentext';
$string['multichoice'] = 'Mehrfachauswahl';
$string['name'] = 'Name';
$string['noanswers'] = 'Es wurden keine Antworten ausgewhlt!';
$string['noattempts'] = 'Diesen Test hat keiner ausgefllt';
$string['nomoreattempts'] = 'Kein Versuch mehr zugelassen';
$string['noquestions'] = 'Es wurden noch keine Fragen eingetragen';
$string['noresponse'] = 'Keine Rckantwort';
$string['noreview'] = 'Sie drfen diesen Test nicht berprfen';
$string['noreviewuntil'] = 'Sie drfen diesen Test bis $a nicht berprfen';
$string['notenoughsubquestions'] = 'Nicht gengend Unter-Fragen wurden definiert\'<br>

Mchten Sie zurck gehen und diese Frage korrigieren?';
$string['numerical'] = 'Numerisch';
$string['paragraphquestion'] = 'Fragezeichen in Zeile $a wird nicht untersttzt. Die Frage wird ignoriert.';
$string['percentcorrect'] = 'Richtig in Prozent';
$string['publish'] = 'Verffentlichen';
$string['qti'] = 'IMS QTI Format';
$string['question'] = 'Frage';
$string['questioninuse'] = 'Die Frage \'$a\' wird momentan benutzt:';
$string['questionname'] = 'Titel der Frage';
$string['questionnametoolong'] = 'Bezeichnung der Frage in Zeile $a ist zu lang (max 255 Zeichen). Er wurde gekrzt.';
$string['questions'] = 'Fragen';
$string['quizavailable'] = 'Dieser Test ist verfgbar bis: $a';
$string['quizclose'] = 'Diesen Test schlieen';
$string['quizclosed'] = 'Dieser Test schliet am $a';
$string['quizcloses'] = 'Test endet';
$string['quiznotavailable'] = 'Dieser Test ist nicht verfgbar bis: $a';
$string['quizopen'] = 'Ein Test beginnen';
$string['random'] = 'Zufllig setzen';
$string['randomcreate'] = 'Eine Zufallsfrage erstellen';
$string['randomsamatch'] = 'Zufllige Kurzantwort-Zuordnungsfrage';
$string['randomsamatchcreate'] = 'Erzeuge zufllige Kurzantwort-Zuordnungsfragen';
$string['randomsamatchintro'] = 'Whlen Sie fr jede der folgenden Fragen die passende Antwort aus dem Men aus';
$string['randomsamatchnumber'] = 'Nummer auszuwhlender Fragen';
$string['readytosend'] = 'Sie sind dabei, Ihr ganzes Test zu senden, um benotet zu werden.  Sind Sie sicher, dass Sie weitermachen wollen?';
$string['recentlyaddedquestion'] = 'Aktuell hinzugefgte Frage!';
$string['regrade'] = 'Alle Versuche zurcksetzen';
$string['regradecomplete'] = 'Alle Versuche wurden zurckgesetzt';
$string['regradecount'] = '$a->changed von $a->attempt Noten wurden gendert';
$string['rename'] = 'Umbenennen';
$string['report'] = 'Berichte';
$string['reportfullstat'] = 'Ausfhrliche Statistik';
$string['reportmulti_percent'] = 'Mehrere Prozentstze';
$string['reportmulti_q_x_student'] = 'Mehrere Teilnehmer/innen Auswahl';
$string['reportmulti_resp'] = 'Individuelle Rckantwort';
$string['reportoverview'] = 'bersicht';
$string['reportregrade'] = 'Versuche zurcksetzen';
$string['reportsimplestat'] = 'Einfache Statistik';
$string['review'] = 'Bericht';
$string['save'] = 'Speichern';
$string['savegrades'] = 'Noten speichern';
$string['savemyanswers'] = 'Meine Antworten auswerten';
$string['savequiz'] = 'Dieses gesamte Test speichern';
$string['score'] = 'Grobe Punktzahl';
$string['select'] = 'Auswhlen';
$string['selectall'] = 'Alles auswhlen';
$string['selectcategoryabove'] = 'Whlen Sie eine obige Kategorie';
$string['shortanswer'] = 'Kurzantwort';
$string['show'] = 'Zeigen';
$string['showcorrectanswer'] = 'Nach dem Antworten richtige Antwort anzeigen?';
$string['showfeedback'] = 'Nach dem Antworten Rckmeldung anzeigen?';
$string['shuffleanswers'] = 'Antworten mischen';
$string['shufflequestions'] = 'Fragen mischen';
$string['time'] = 'Zeit';
$string['timecompleted'] = 'Beendet';
$string['timetaken'] = 'Verbrauchte Zeit';
$string['toomanyrandom'] = 'Die Anzahl der bentigten Zufallsfragen ist grer als die, die die Kategorie enthlt! ($a)';
$string['true'] = 'Wahr';
$string['truefalse'] = 'Wahr/Falsch';
$string['type'] = 'Typ';
$string['unknowntype'] = 'Fragentyp in Zeile $a wird nicht untersttzt. Die Frage wird ignoriert.';
$string['viewallanswers'] = 'Zeige $a ausgefllte Test';
$string['viewallreports'] = 'Berichte ansehen fr $a Versuche';
$string['warningsdetected'] = '$a Warnung(en) entdeckt';
$string['webct'] = 'WebCT Format';
$string['withsummary'] = 'mit zusammfassender Statistik';
$string['wronggrade'] = 'Falsche Bewertung (nach Zeile $a):';
$string['yourfinalgradeis'] = 'Ihre Gesamtnote fr diesen Test ist $a';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/de/quiz.php <==
<?PHP // $Id$ 
      // quiz.php - created with Moodle 1.4 aiming-for-beta-soon (2004082200)


$string['acceptederror'] = 'Akzeptierter Fehler';
$string['addingquestions'] = 'Diese Spalte der Seite ist zum Verwalten von Testfragen. Fragen werden in Kategorien gespeichert, um sie besser organisieren zu knnen, und knnen von jedem Test Ihres Kurses oder sogar von anderen Kursen (Wenn man \'verffentlichen\' ausgewhlt hat) benutzt werden. <br /><br />Nachdem Sie eine Kategorie erzeugt haben, knnen Sie Fragen erzeugen oder bearbeiten. Sie knnen jede dieser Fragen auswhlen und Ihrem Test in der anderen Spalte hinzufgen.';
$string['addquestions'] = 'Fragen hinzufgen';
$string['addquestionstoquiz'] = 'Frage zu aktuellem Test hinzufgen';
$string['addselectedtoquiz'] = 'Auswahl zum Test hinzufgen';
$string['aiken'] = 'Aiken Format';
$string['allowreview'] = 'Bericht erlauben';
$string['alreadysubmitted'] = 'Es sieht so aus, als htten Sie diesen Versuch schon eingetragen';
$string['alternativeunits'] = 'Alternative Einheiten';
$string['alwaysavailable'] = 'Immer verfgbar';
$string['answer'] = 'Antwort';
$string['answerhowmany'] = 'Eine oder mehrere Antworten?';
$string['answersingleno'] = 'Mehrere Antworten erlaubt';
$string['answersingleyes'] = 'Nur eine Antwort';
$string['answerswithacceptederrormarginmustbenumeric'] = 'Antworten mit akzeptiertem Fehler';
$string['answertoolong'] = 'Die Antwort ist nach Zeile $a zu lang (Sie knnen bis zu 255 Zeichen eingeben).';
$string['aon'] = 'AON Format';
$string['attempt'] = 'Versuch $a';
$string['attemptfirst'] = 'Erster Versuch';
$string['attemptincomplete'] = 'Dieser Versuch von $a ist noch nicht vollstndig abgeschlossen.';
$string['attemptlast'] = 'Letzter Versuch';
$string['attemptquiznow'] = 'Test jetzt probieren';
$string['attempts'] = 'Versuche';
$string['attemptsallowed'] = 'Erlaubte Versuche';
$string['attemptsexist'] = 'Dieser Test wurde bereits von Ihnen durchgefhrt.';
$string['attemptsunlimited'] = 'Unbegrenzte Versuche';
$string['backtoquiz'] = 'Zurck zur Testbearbeitung';
$string['bestgrade'] = 'Bestnote';
$string['blackboard'] = 'Blackboard (Lernmanagementsystem)';
$string['calculated'] = 'Berechnung';
$string['calculatedquestion'] = 'Die berechnete Frage in Zeile $a wird nicht untersttzt. Die Frage wird ignoriert.';
$string['caseno'] = 'Nein, Schreibweise ist unwichtig';
$string['casesensitive'] = 'Schreibweise';
$string['caseyes'] = 'Ja, Schreibweise muss stimmen';
$string['categories'] = 'Kategorien';
$string['category'] = 'Kategorie';
$string['categoryinfo'] = 'Kategorie-Information';
$string['categorymove'] = 'Die Kategorie \'$a->name\' enthlt $a->count Fragen. Bitte whlen Sie eine andere Kategorie, um sie zu verschieben.';
$string['categorymoveto'] = 'In diese Kategorie verschieben';
$string['checkanswer'] = 'Prfen';
$string['choice'] = 'Auswahl';
$string['choices'] = 'Verfgbare Auswahl';
$string['choosedatasetproperties'] = 'Datensatzeigenschaften auswhlen';
$string['close'] = 'Vorschau schlieen';
$string['confirmstartattempt'] = 'Der Test muss in einer festgelegten Zeit bearbeitet werrden. Sind Sie sicher, dass Sie jetzt beginnen wollen?';
$string['correctanswer'] = 'Richtige Antwort';
$string['correctanswerformula'] = 'Formel fr richtige Antwort';
$string['correctanswerlength'] = 'Signifikante Zahlen';
$string['correctanswers'] = 'Richtige Antworten';
$string['corrresp'] = 'richtige Rckantwort';
$string['countdown'] = 'Countdown';
$string['countdownfinished'] = 'Das Test ist beendet, Sie sollten Ihre Antworten jetzt absenden.';
$string['countdowntenminutes'] = 'Das Test endet in 10 Minuten.';
$string['coursetestmanager'] = 'Kurstest Managerformat';
$string['createmultiple'] = 'Mehrere Fragen erstellen';
$string['createnewquestion'] = 'Eine neue Frage anlegen';
$string['custom'] = 'Eigenes Format';
$string['datasetdefinitions'] = 'Wiederverwendbare Datensatzdefinitionen fr Kategorie $a';
$string['datasetnumber'] = 'Anzahl';
$string['daysavailable'] = 'Tage verfgbar';
$string['decimals'] = 'mit $a';
$string['default'] = 'Standard';
$string['defaultgrade'] = 'Standard-Note der Frage';
$string['defaultinfo'] = 'Die Standard-Kategorie fr diese Frage';
$string['deleteattemptcheck'] = 'Sind Sie wirklich sicher, dass Sie diese Versuche lschen wollen?';
$string['deletequestioncheck'] = 'Sind Sie sich absolut sicher, dass Sie \'$a\' lschen mchten?';
$string['description'] = 'Beschreibung';
$string['discrimination'] = 'Index fr die Abgrenzung';
$string['eachattemptbuildsonthelast'] = 'Jeder Versuch basiert auf dem Letzten';
$string['editcategories'] = 'Kategorien bearbeiten';
$string['editdatasets'] = 'Datensatz bearbeiten';
$string['editingcalculated'] = 'Bearbeiten einer  Rechen-Frage';
$string['editingdescription'] = 'Eine Beschreibung bearbeiten';
$string['editingmatch'] = 'Eine Zuordnungsfrage bearbeiten';
$string['editingmultianswer'] = 'Eine Frage mit Lckentext bearbeiten';
$string['editingmultichoice'] = 'Eine Frage mit Mehrfachauswahl bearbeiten';
$string['editingnumerical'] = 'Eine numerische Frage bearbeiten';
$string['editingquestion'] = 'Eine Frage bearbeiten';
$string['editingquiz'] = 'Einen Test bearbeiten';
$string['editingrandom'] = 'Eine zufllige Frage bearbeiten';
$string['editingrandomsamatch'] = 'Eine zufllige Kurzantwort-Zuordnung bearbeiten ';
$string['editingshortanswer'] = 'Kurzantwort der Frage bearbeiten';
$string['editingtruefalse'] = 'Ja/Nein-Frage bearbeiten';
$string['editquestions'] = 'Fragen bearbeiten';
$string['errorsdetected'] = '$a Fehler entdeckt';
$string['exportfilename'] = 'Test';
$string['exportname'] = 'Dateiname';
$string['exportnameformat'] = '%%J%%M%%T-%%H%%M';
$string['exportquestions'] = 'Fragen in Datei exportieren';
$string['false'] = 'Falsch';
$string['feedback'] = 'Rckmeldung';
$string['file'] = 'Datei';
$string['fileformat'] = 'Dateiformat';
$string['filloutoneanswer'] = 'Sie mssen mindestens eine mgliche Antwort geben. Leere Antworten werden ignoriert.';
$string['filloutthreequestions'] = 'Sie mssen mindestens 3 Fragen auswhlen. Leere Fragen werden nicht verwendet';
$string['fillouttwochoices'] = 'Sie mssen mindestens zwei mgliche Antwort geben. Leere Antworten werden ignoriert.';
$string['forceregeneration'] = 'erzwungene Wiederherstellung';
$string['fractionsaddwrong'] = 'Ihre positiven gewhlten Punktzahlen ergeben keine 100%%

<br />Statt dessen ergeben Sie $a%%

<br />Mchten Sie zurck gehen und diese Frage korrigieren?';
$string['fractionsnomax'] = 'Eine dieser Antworten sollte 100%% sein, so dass
<br />es mglich ist, die volle Punktzahl fr diese Frage zu bekommen.

<br />Mchten Sie zurck gehen und diese Frage korrigieren?';
$string['functiontakesatleasttwo'] = 'Die Funktion $a erfordert mindestens zwei Eintrge';
$string['functiontakesnoargs'] = 'Die Funktion $a hat keine Eintrge';
$string['functiontakesonearg'] = 'Die Funktion $a erfordert genau einen Eintrag';
$string['functiontakesoneortwoargs'] = 'Die Funktion $a erfordert entweder einen oder zwei Eintrge';
$string['functiontakestwoargs'] = 'Die Funktion $a erfordert genau zwei Eintrge';
$string['generatevalue'] = 'Erstelle einen neuen Wert zwischen';
$string['geometric'] = 'Geometrisch';
$string['gift'] = 'GIFT Format';
$string['gradeaverage'] = 'Durchschnittsnote';
$string['gradehighest'] = 'Beste Note';
$string['grademethod'] = 'Bewertungsschema';
$string['guestsno'] = 'Entschuldigung, aber Gste knnen den Test nicht sehen oder probieren.';
$string['illegalformulasyntax'] = 'Fehlerhafte Formel-Syntax beginnend mit $a';
$string['imagedisplay'] = 'Bild fr die Anzeige';
$string['imagemissing'] = 'Bild in Zeile $a nicht verfgbar. Der Dateiname wird ignoriert';
$string['importquestions'] = 'Eine Frage aus einer Datei importieren';
$string['indivresp'] = 'Rckantwort fr jeden zu jeder Position';
$string['introduction'] = 'Einleitung';
$string['itemanal'] = 'Antwortanalyse des Elements';
$string['itemdefinition'] = 'Definition';
$string['link'] = 'Link';
$string['listitems'] = 'Liste der Elementes des Tests';
$string['marks'] = 'Punkte';
$string['match'] = 'Zuordnung';
$string['matchanswer'] = 'zugeordnete Antwort';
$string['max'] = 'Max';
$string['min'] = 'Min';
$string['minutes'] = 'Minuten';
$string['missinganswer'] = 'Zu wenig :Antworten, :Lx, :Rx Antworten fr Zeile $a. Sie mssen mindestens zwei mgliche Antworten eingeben';
$string['missingcorrectanswer'] = 'Die korrekte Antwort muss angegeben werden';
$string['missingname'] = 'Der Name der Frage fehlt';
$string['missingquestion'] = 'Fehlendes Fragezeichen nach Zeile $a';
$string['missingquestiontext'] = 'Der Text der Frage fehlt';
$string['missingword'] = 'Das Wortformat fehlt';
$string['modulename'] = 'Test';
$string['modulenameplural'] = 'Tests';
$string['multianswer'] = 'Lckentext';
$string['multichoice'] = 'Mehrfachauswahl';
$string['multiplier'] = 'Multiplikator';
$string['name'] = 'Name';
$string['noanswers'] = 'Es wurden keine Antworten ausgewhlt!';
$string['noattempts'] = 'Diesen Test hat keiner ausgefllt';
$string['nodataset'] = 'nichts - es gibt keine Wild-Card';
$string['nominal'] = 'Nominal';
$string['nomoreattempts'] = 'Kein Versuch mehr zugelassen';
$string['nopossibledatasets'] = 'Keine Datenstze mglich';
$string['noquestions'] = 'Es wurden noch keine Fragen eingetragen';
$string['noresponse'] = 'Keine Rckantwort';
$string['noreview'] = 'Sie drfen diesen Test nicht berprfen';
$string['noreviewuntil'] = 'Sie drfen diesen Test bis $a nicht berprfen';
$string['noscript'] = 'JavaScript mu aktiviert sein, um fortzusetzen';
$string['notenoughanswers'] = 'Diese Art von Fragen erfordert zumindest $a Antworten';
$string['notenoughsubquestions'] = 'Nicht gengend Unter-Fragen wurden definiert\'<br />

Mchten Sie zurck gehen und diese Frage korrigieren?';
$string['numerical'] = 'Numerisch';
$string['optional'] = 'optional';
$string['overdue'] = 'berfllig';
$string['paragraphquestion'] = 'Fragezeichen in Zeile $a wird nicht untersttzt. Die Frage wird ignoriert.';
$string['passworderror'] = 'Das eingegebene Passwort war falsch';
$string['percentcorrect'] = 'Richtig in Prozent';
$string['preview'] = 'Vorschau';
$string['previewquestion'] = 'Vorschau der Frage';
$string['publish'] = 'Verffentlichen';
$string['publishedit'] = 'Um Fragen in dieser Kategorie zu bearbeiten, mssen Sie ber die erforderlichen Rechte verfgen';
$string['qti'] = 'IMS QTI Format';
$string['question'] = 'Frage';
$string['questioninuse'] = 'Die Frage \'$a\' wird momentan benutzt:';
$string['questionname'] = 'Titel der Frage';
$string['questionnametoolong'] = 'Bezeichnung der Frage in Zeile $a ist zu lang (max 255 Zeichen). Er wurde gekrzt.';
$string['questions'] = 'Fragen';
$string['quizavailable'] = 'Dieser Test ist verfgbar bis: $a';
$string['quizclose'] = 'Diesen Test schlieen';
$string['quizclosed'] = 'Dieser Test schliet am $a';
$string['quizcloses'] = 'Test endet';
$string['quiznotavailable'] = 'Dieser Test ist nicht verfgbar bis: $a';
$string['quizopen'] = 'Ein Test beginnen';
$string['quizopens'] = 'Test hat begonnen';
$string['quiztimelimit'] = 'Zeitbegrenzung:$a';
$string['quiztimer'] = 'Testuhr';
$string['random'] = 'Zufllig setzen';
$string['randomcreate'] = 'Eine Zufallsfrage erstellen';
$string['randomsamatch'] = 'Zufllige Kurzantwort-Zuordnungsfrage';
$string['randomsamatchcreate'] = 'Erzeuge zufllige Kurzantwort-Zuordnungsfragen';
$string['randomsamatchintro'] = 'Whlen Sie fr jede der folgenden Fragen die passende Antwort aus dem Men aus';
$string['randomsamatchnumber'] = 'Nummer auszuwhlender Fragen';
$string['readytosend'] = 'Sie sind dabei, Ihr ganzes Test zu senden, um benotet zu werden.  Sind Sie sicher, dass Sie weitermachen wollen?';
$string['recentlyaddedquestion'] = 'Aktuell hinzugefgte Frage!';
$string['regrade'] = 'Alle Versuche zurcksetzen';
$string['regradecomplete'] = 'Alle Versuche wurden zurckgesetzt';
$string['regradecount'] = '$a->changed von $a->attempt Noten wurden gendert';
$string['relative'] = 'Relativ';
$string['remove'] = 'Entfernen';
$string['rename'] = 'Umbenennen';
$string['report'] = 'Berichte';
$string['reportfullstat'] = 'Ausfhrliche Statistik';
$string['reportmulti_percent'] = 'Mehrere Prozentstze';
$string['reportmulti_q_x_student'] = 'Mehrere Teilnehmer/innen Auswahl';
$string['reportmulti_resp'] = 'Individuelle Rckantwort';
$string['reportoverview'] = 'bersicht';
$string['reportregrade'] = 'Versuche zurcksetzen';
$string['reportsimplestat'] = 'Einfache Statistik';
$string['requirepassword'] = 'Erfordert Passwort';
$string['requirepasswordmessage'] = 'Zur Teilnahme am Test bentigen Sie ein Passwort';
$string['requiresubnet'] = 'Netzwerk-Adresse erforderlich';
$string['review'] = 'Bericht';
$string['save'] = 'Speichern';
$string['savegrades'] = 'Noten speichern';
$string['savemyanswers'] = 'Meine Antworten auswerten';
$string['savequiz'] = 'Dieses gesamte Test speichern';
$string['score'] = 'Grobe Punktzahl';
$string['select'] = 'Auswhlen';
$string['selectall'] = 'Alles auswhlen';
$string['selectcategoryabove'] = 'Whlen Sie eine obige Kategorie';
$string['shortanswer'] = 'Kurzantwort';
$string['show'] = 'Zeigen';
$string['showcorrectanswer'] = 'Nach dem Antworten richtige Antwort anzeigen?';
$string['showfeedback'] = 'Nach dem Antworten Rckmeldung anzeigen?';
$string['shuffleanswers'] = 'Antworten mischen';
$string['shufflequestions'] = 'Fragen mischen';
$string['significantfigures'] = 'mit $a';
$string['subneterror'] = 'Entschuldigung, der Zugriff auf den Test ist nur von bestimmten Rechnern mglich. Ihr Computer kann den Test zur Zeit nicht starten.';
$string['substitutedby'] = 'wird ersetzt durch';
$string['time'] = 'Zeit';
$string['timecompleted'] = 'Beendet';
$string['timeleft'] = 'Verbleibende Zeit';
$string['timelimit'] = 'Zeitbegrenzung';
$string['timelimitexeeded'] = 'Die Zeitbegrenzung fr den Test ist abgelaufen.';
$string['timesup'] = 'Zeitraum ist abgelaufen';
$string['timetaken'] = 'Verbrauchte Zeit';
$string['tolerance'] = 'Toleranz';
$string['toomanyrandom'] = 'Die Anzahl der bentigten Zufallsfragen ist grer als die, die die Kategorie enthlt! ($a)';
$string['true'] = 'Wahr';
$string['truefalse'] = 'Wahr/Falsch';
$string['type'] = 'Typ';
$string['unit'] = 'Einheit';
$string['unknowntype'] = 'Fragentyp in Zeile $a wird nicht untersttzt. Die Frage wird ignoriert.';
$string['unsupportedformulafunction'] = 'Die Funktion $a wird nicht untersttzt';
$string['viewallanswers'] = 'Zeige $a ausgefllte Test';
$string['viewallreports'] = 'Berichte ansehen fr $a Versuche';
$string['warningsdetected'] = '$a Warnung(en) entdeckt';
$string['webct'] = 'WebCT Format';
$string['wildcard'] = 'Wild Card';
$string['withsummary'] = 'mit zusammfassender Statistik';
$string['wronggrade'] = 'Falsche Bewertung (nach Zeile $a):';
$string['xml'] = 'moodle XML Format';
$string['yourfinalgradeis'] = 'Ihre Gesamtnote fr diesen Test ist $a';

?>
